package com.gentics.portal.node.connector.examples;

import java.util.Properties;

import org.apache.log4j.PropertyConfigurator;

import com.gentics.api.lib.datasource.Datasource;
import com.gentics.api.lib.resolving.Resolvable;
import com.gentics.api.portalnode.connector.PortalConnectorFactory;

/**
 * A very simple example on how to create a Datasource connection and retrieve a
 * single content object from a Gentics Content.Node contentrepository.
 */
public class SimplePortalConnectorExample {
    private static String TEST_CONTENTID = "10007.10000";

    /**
     * @param args
     */
    public static void main(String[] args) {
        // Initialize log4j
        PropertyConfigurator.configure(SimplePortalConnectorExample.class.getResource("logging.properties"));
        Datasource ds;
        try {
            // Get our Datasource connection.
            ds = getDatasource();
            // Retrieve the specified content object.
            Resolvable contentobject = PortalConnectorFactory.getContentObject(TEST_CONTENTID,
                    ds);

            // Output the name to see that it worked.
            // (name has an attribute type 1 - Text (Short))
            String name = (String) contentobject.get("name");
            System.out.println("Retrieved content object of name: " + name);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Create the datasource
     * @return datasource
     */
    protected static Datasource getDatasource() throws Exception {
        Properties handleProperties = new Properties();
        // Load the properties for the datasource connection from the
        // filesystem.
        handleProperties.load(SimplePortalConnectorExample.class
                .getResourceAsStream("jdbc-handle.properties"));
        // for usage of jndi datasources:
        // handleProperties.load(DatasourceAccess.class.getResourceAsStream("jndi-handle.properties"));

        return PortalConnectorFactory.createDatasource(handleProperties);
    }

}
